import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { CostExplorerClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CostExplorerClient";
import { GetReservationPurchaseRecommendationRequest, GetReservationPurchaseRecommendationResponse } from "../models/models_0";
/**
 * The input for {@link GetReservationPurchaseRecommendationCommand}.
 */
export interface GetReservationPurchaseRecommendationCommandInput extends GetReservationPurchaseRecommendationRequest {
}
/**
 * The output of {@link GetReservationPurchaseRecommendationCommand}.
 */
export interface GetReservationPurchaseRecommendationCommandOutput extends GetReservationPurchaseRecommendationResponse, __MetadataBearer {
}
/**
 * <p>Gets recommendations for reservation purchases. These recommendations might help you to
 *       reduce your costs. Reservations provide a discounted hourly rate (up to 75%) compared to
 *       On-Demand pricing.</p>
 *          <p>Amazon Web Services generates your recommendations by identifying your On-Demand usage
 *       during a specific time period and collecting your usage into categories that are eligible for
 *       a reservation. After Amazon Web Services has these categories, it simulates every combination
 *       of reservations in each category of usage to identify the best number of each type of Reserved
 *       Instance (RI) to purchase to maximize your estimated savings. </p>
 *          <p>For example, Amazon Web Services automatically aggregates your Amazon EC2 Linux, shared
 *       tenancy, and c4 family usage in the US West (Oregon) Region and recommends that you buy
 *       size-flexible regional reservations to apply to the c4 family usage. Amazon Web Services
 *       recommends the smallest size instance in an instance family. This makes it easier to purchase
 *       a size-flexible Reserved Instance (RI). Amazon Web Services also shows the equal number of
 *       normalized units. This way, you can purchase any instance size that you want. For this
 *       example, your RI recommendation is for <code>c4.large</code> because that is the smallest size
 *       instance in the c4 instance family.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CostExplorerClient, GetReservationPurchaseRecommendationCommand } from "@aws-sdk/client-cost-explorer"; // ES Modules import
 * // const { CostExplorerClient, GetReservationPurchaseRecommendationCommand } = require("@aws-sdk/client-cost-explorer"); // CommonJS import
 * const client = new CostExplorerClient(config);
 * const command = new GetReservationPurchaseRecommendationCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link GetReservationPurchaseRecommendationCommandInput} for command's `input` shape.
 * @see {@link GetReservationPurchaseRecommendationCommandOutput} for command's `response` shape.
 * @see {@link CostExplorerClientResolvedConfig | config} for CostExplorerClient's `config` shape.
 *
 * @throws {@link DataUnavailableException} (client fault)
 *  <p>The requested data is unavailable.</p>
 *
 * @throws {@link InvalidNextTokenException} (client fault)
 *  <p>The pagination token is invalid. Try again without a pagination token.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>You made too many calls in a short period of time. Try again later.</p>
 *
 *
 */
export declare class GetReservationPurchaseRecommendationCommand extends $Command<GetReservationPurchaseRecommendationCommandInput, GetReservationPurchaseRecommendationCommandOutput, CostExplorerClientResolvedConfig> {
    readonly input: GetReservationPurchaseRecommendationCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: GetReservationPurchaseRecommendationCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: CostExplorerClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetReservationPurchaseRecommendationCommandInput, GetReservationPurchaseRecommendationCommandOutput>;
    private serialize;
    private deserialize;
}
